searchData={"items":[{"type":"module","title":"Varint.LEB128","doc":"This module provides functions to convert unsigned integers to and from LEB128 encoded integers.\n\n    iex> Varint.LEB128.encode(12345)\n    <<185, 96>>\n\n    iex> Varint.LEB128.decode(<<185, 96>>)\n    {12345, <<>>}\n\nNote that if you intend to work with signed integers, you'll need the Zigzag module as well:\n\n    iex> -10 |> Varint.Zigzag.encode() |> Varint.LEB128.encode()\n    <<19>>\n\n    iex> <<19>> |> Varint.LEB128.decode() |> elem(0) |> Varint.Zigzag.decode()\n    -10","ref":"Varint.LEB128.html"},{"type":"function","title":"Varint.LEB128.decode/1","doc":"Decodes LEB128 encoded bytes to an unsigned integer.\n\n  Returns a tuple where the first element is the decoded value and the second\n  element the bytes which have not been parsed.\n\n  This function will raise `ArgumentError` if the given `b` is not a valid LEB128 integer.\n\n    iex> Varint.LEB128.decode(<<172, 2>>)\n    {300, <<>>}\n\n    iex> Varint.LEB128.decode(<<172, 2, 0>>)\n    {300, <<0>>}\n\n    iex> Varint.LEB128.decode(<<0>>)\n    {0, <<>>}\n\n    iex> Varint.LEB128.decode(<<1>>)\n    {1, <<>>}\n\n    iex> Varint.LEB128.decode(<<218>>)\n    ** (ArgumentError) not a valid LEB128 encoded integer","ref":"Varint.LEB128.html#decode/1"},{"type":"function","title":"Varint.LEB128.encode/1","doc":"Encodes an unsigned integer using LEB128 compression.\n\n    iex> Varint.LEB128.encode(300)\n    <<172, 2>>\n\n    iex> Varint.LEB128.encode(0)\n    <<0>>\n\n    iex> Varint.LEB128.encode(1)\n    <<1>>","ref":"Varint.LEB128.html#encode/1"},{"type":"module","title":"Varint.Zigzag","doc":"This module provides functions to work with signed integers in conjunction with\nLEB128 encoding.","ref":"Varint.Zigzag.html"},{"type":"function","title":"Varint.Zigzag.decode/1","doc":"Decodes an unsigned integer into a signed integer.\n\n    iex> Varint.Zigzag.decode(0)\n    0\n\n    iex> Varint.Zigzag.decode(1)\n    -1\n\n    iex> Varint.Zigzag.decode(2)\n    1\n\n    iex> Varint.Zigzag.decode(3)\n    -2\n\n    iex> Varint.Zigzag.decode(4294967294)\n    2147483647\n\n    iex> Varint.Zigzag.decode(4294967295)\n    -2147483648","ref":"Varint.Zigzag.html#decode/1"},{"type":"function","title":"Varint.Zigzag.encode/1","doc":"Encodes a signed integer into an unsigned integer suitable for LEB128 encoding.\n\n    iex> Varint.Zigzag.encode(0)\n    0\n\n    iex> Varint.Zigzag.encode(-1)\n    1\n\n    iex> Varint.Zigzag.encode(1)\n    2\n\n    iex> Varint.Zigzag.encode(-2)\n    3\n\n    iex> Varint.Zigzag.encode(-2147483648)\n    4294967295\n\n    iex> Varint.Zigzag.encode(2147483647)\n    4294967294","ref":"Varint.Zigzag.html#encode/1"},{"type":"extras","title":"Varint","doc":"# Varint\n\n[![Elixir CI](https://github.com/ahamez/varint/actions/workflows/elixir.yml/badge.svg)](https://github.com/ahamez/varint/actions/workflows/elixir.yml) [![Coverage Status](https://coveralls.io/repos/github/ahamez/varint/badge.svg?branch=master)](https://coveralls.io/github/ahamez/varint?branch=master) [![Hex.pm](https://img.shields.io/hexpm/v/varint)](https://hex.pm/packages/varint) [![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/varint/) [![License](https://img.shields.io/hexpm/l/varint.svg)](https://github.com/ahamez/varint/blob/master/LICENSE)\n\nA library to compress integers using [LEB128](https://en.wikipedia.org/wiki/LEB128).","ref":"readme.html"},{"type":"extras","title":"Installation - Varint","doc":"Add `:varint` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:varint, \"~> 1.4\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Varint","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"LEB128 - Varint","doc":"Use this module to compress and decompress unsigned integers:\n\n```elixir\niex> Varint.LEB128.encode(300)\n<<172, 2>>\n```\n\n```elixir\niex> Varint.LEB128.decode(<<172, 2>>)\n{300, <<>>}\n```\n\n#","ref":"readme.html#leb128"},{"type":"extras","title":"Zigzag - Varint","doc":"As LEB128 works with unsigned integers, you can use the the Zigzag module to process signed integers.\n\n```elixir\niex> Varint.Zigzag.encode(-2)\n3\n```\n\n```elixir\niex> Varint.Zigzag.decode(3)\n-2\n```\n\n```elixir\niex> Varint.Zigzag.encode(2)\n4\n```\n\n```elixir\niex> Varint.Zigzag.decode(4)\n2\n```\n\nYou'll find detailed instructions at [hexdocs.pm](https://hexdocs.pm/varint/api-reference.html).","ref":"readme.html#zigzag"},{"type":"extras","title":"License - Varint","doc":"Copyright (c) 2016 Alexandre Hamez\n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the LICENSE file for more details.","ref":"readme.html#license"}],"content_type":"text/markdown"}